@@ -1,9 +1,11 @@
+//go:build js && wasm
+
 package main
 
 import (
 	"html/template"
 	"strings"
-	"syscall/js" // nolint
+	"syscall/js"
 
 	tree "github.com/ddddddO/gtree"
 )
@@ -32,8 +34,10 @@ func gtree(this js.Value, args []js.Value) interface{} {
 	if err := tree.Output(
 		writer,
 		strings.NewReader(getElementByID("in").Get("value").String()),
-		tree.WithBranchFormatLastNode(parts1+parts3, "    "),
-		tree.WithBranchFormatIntermedialNode(parts2+parts3, parts4+"   "),
+		tree.WithLastBranch(parts1),
+		tree.WithMidBranch(parts2),
+		tree.WithHLine(parts3),
+		tree.WithVLine(parts4),
 	); err != nil {
 		// リアルタイムで tree 生成するようにし、ダイアログでエラー出したくないので、コメントアウトしておく
 		// alert(err.Error())
