@@ -22,7 +22,7 @@ type treePipeline struct {
 var _ tree = (*treePipeline)(nil)
 
 func newTreePipeline(cfg *config) tree {
-	growerFactory := func(lastNodeFormat, intermedialNodeFormat branchFormat, dryrun bool, encode encode) growerPipeline {
+	growerFactory := func(lastNodeFormat, intermedialNodeFormat *branchFormat, dryrun bool, encode encode) growerPipeline {
 		if encode != encodeDefault {
 			return newNopGrowerPipeline()
 		}
