@@ -22,8 +22,10 @@ func TestWalkFromRoot(t *testing.T) {
 			name: "case(succeeded)",
 			root: tu.PrepareMultiNode(),
 			options: []gtree.Option{
-				gtree.WithBranchFormatIntermedialNode("+--", ":   "),
-				gtree.WithBranchFormatLastNode("+--", "    "),
+				gtree.WithMidBranch("+--"),
+				gtree.WithLastBranch("+--"),
+				gtree.WithHLine(""),
+				gtree.WithVLine(":"),
 			},
 			out: out{
 				output: strings.TrimLeft(`
@@ -36,6 +38,29 @@ root1
 :           +-- child 6
 :               +-- child 7
 +-- child 8
+`, "\n"),
+				err: nil,
+			},
+		},
+		{
+			name: "case(succeeded / allowed duplicate nodes)",
+			root: tu.PrepareMultiNodeWithDuplicationAllowed(),
+			out: out{
+				output: strings.TrimLeft(`
+root1
+├── child 1
+│   └── child 2
+│       └── child 3
+├── child 1
+│   └── child 2
+│       └── child 4
+│           ├── child 5
+│           ├── child 5
+│           ├── child 6
+│           │   └── child 7
+│           └── child 6
+│               └── child 9
+└── child 8
 `, "\n"),
 				err: nil,
 			},
@@ -90,8 +115,10 @@ func TestWalkIterFromRoot(t *testing.T) {
 			name: "case(succeeded)",
 			root: tu.PrepareMultiNode(),
 			options: []gtree.Option{
-				gtree.WithBranchFormatIntermedialNode("+--", ":   "),
-				gtree.WithBranchFormatLastNode("+--", "    "),
+				gtree.WithMidBranch("+--"),
+				gtree.WithLastBranch("+--"),
+				gtree.WithHLine(""),
+				gtree.WithVLine(":"),
 			},
 			out: out{
 				output: strings.TrimLeft(`
@@ -104,6 +131,29 @@ root1
 :           +-- child 6
 :               +-- child 7
 +-- child 8
+`, "\n"),
+				err: nil,
+			},
+		},
+		{
+			name: "case(succeeded / allowed duplicate nodes)",
+			root: tu.PrepareMultiNodeWithDuplicationAllowed(),
+			out: out{
+				output: strings.TrimLeft(`
+root1
+├── child 1
+│   └── child 2
+│       └── child 3
+├── child 1
+│   └── child 2
+│       └── child 4
+│           ├── child 5
+│           ├── child 5
+│           ├── child 6
+│           │   └── child 7
+│           └── child 6
+│               └── child 9
+└── child 8
 `, "\n"),
 				err: nil,
 			},
